import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import styles from './index.module.scss';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var getUIState = function getUIState(_ref) {
  var isDisabled = _ref.isDisabled,
      hasError = _ref.hasError;

  if (isDisabled) {
    return 'disabled';
  }

  if (hasError) {
    return 'error';
  }

  return 'default';
};

var Label = function Label(_ref2) {
  var _classNames;

  var isDisabled = _ref2.isDisabled,
      hasError = _ref2.hasError,
      forProp = _ref2.for,
      dataTest = _ref2.dataTest,
      children = _ref2.children;
  var uiState = getUIState({
    isDisabled: isDisabled,
    hasError: hasError
  });
  return (// eslint-disable-next-line jsx-a11y/label-has-for
    React.createElement("label", {
      htmlFor: forProp,
      className: classNames((_classNames = {}, _defineProperty(_classNames, styles.text, true), _defineProperty(_classNames, styles.textUiStateDisabled, uiState === 'disabled'), _defineProperty(_classNames, styles.textUiStateError, uiState === 'error'), _defineProperty(_classNames, styles.textUiStateDefault, uiState === 'default'), _classNames)),
      "data-test": dataTest
    }, children)
  );
};

Label.propTypes = {
  /**
   * The label text that appears above the form element.
   */
  children: PropTypes.node,

  /**
   * `id` of the form field that's associated with the `label`. Clicking on the label text will
   * switch the browser's focus to the form field.
   *
   * The Label's `for` and form field's `id` prop must match and be unique to the page. You can
   * use [Lodash's `uniqueId`](https://lodash.com/docs/4.17.10#uniqueId) to generate a unique id.
   */
  for: PropTypes.string,

  /**
   * Visually disable the label.
   */
  isDisabled: PropTypes.bool,

  /**
   * Changes the label text color to red.
   */
  hasError: PropTypes.bool,

  /**
   * A selector hook into the React component for use in automated testing environments.
   */
  dataTest: PropTypes.string
};
Label.defaultProps = {
  children: null,
  isDisabled: false,
  hasError: false,
  for: undefined,
  dataTest: undefined
};

export default Label;
//# sourceMappingURL=index.es.js.map
